==> macdaily-2018.8.31.tar.gz: macdaily-2018.8.31/macdaily/libprinstall/reinstall_cask.sh <==
#!/bin/bash


# clear potential terminal buffer
sript -q /dev/null tput clear > /dev/null 2>&1


# terminal display
reset="\033[0m"         # reset
bold="\033[1m"          # bold
red="\033[91m"          # bright red foreground
green="\033[92m"        # bright green foreground
yellow="\033[93m"       # bright yellow foreground


################################################################################
# Reinstall Caskroom packages.
#
# Parameter list:
#   1. Encrypted Password
#   2. Log File
#   3. Temp File
#   4. Quiet Flag
#   5. Verbose Flag
#   6. Package
#       ............
################################################################################


# parameter assignment
password=`python -c "print(__import__('base64').b64decode(__import__('sys').stdin.readline().strip()).decode())" <<< $1`
# echo $1 | cut -c2- | rev | cut -c2- | rev
logfile=`python -c "print(__import__('sys').stdin.readline().strip().strip('\''))" <<< $2`
tmpfile=`python -c "print(__import__('sys').stdin.readline().strip().strip('\''))" <<< $3`
arg_q=$4
arg_v=$5
arg_pkg=${*:6}


# remove /tmp/log/reinstall.log
rm -f "$tmpfile"


# create /tmp/log/reinstall.log & /Library/Logs/Scripts/reinstall/logdate.log
touch "$logfile"
touch "$tmpfile"


# log current status
echo "- /bin/bash $0 $@" >> "$tmpfile"


# log commands
logprefix="script -aq "$tmpfile""
if ( $arg_q ) ; then
    logsuffix="grep ^$"
else
    logsuffix="grep ^.*$"
fi


# if quiet flag set
if ( $arg_q ) ; then
    quiet="--quiet"
else
    quiet=""
fi


# if verbose flag set
if ( $arg_v ) ; then
    verbose="--verbose"
else
    verbose=""
fi


# reinstall procedure
for name in $arg_pkg ; do
    flag=`brew cask list -1 | awk "/^$name$/"`
    if [[ ! -z $flag ]] ; then
        # ask for password up-front
        sudo --reset-timestamp
        sudo --stdin --validate <<< $password ; echo

        $logprefix printf "+ ${bold}brew cask reinstall $name $verbose $quiet${reset}\n" | $logsuffix
        if ( $arg_q ) ; then
            $logprefix brew cask reinstall $name $verbose $quiet > /dev/null 2>&1
        else
            $logprefix brew cask reinstall $name $verbose $quiet
        fi
        $logprefix echo | $logsuffix
    else
        $logprefix printf "reinstall: ${yellow}brew${reset}: no formula names ${red}$name${reset} installed\n" | $logsuffix

        # did you mean
        tmp=`brew list -1 | grep $name | xargs`
        if [[ ! -z $tmp ]] ; then
            dym=`python -c "print('${red}' + '${reset}, ${red}'.join(__import__('sys').stdin.read().strip().split()) + '${reset}')" <<< $tmp`
            $logprefix printf "reinstall: ${yellow}brew${reset}: did you mean any of the following formulae: $dym?\n" | $logsuffix
        fi
        $logprefix echo | $logsuffix
    fi
done


# aftermath works
bash ./libprinstall/aftermath.sh ""$logfile"" ""$tmpfile"" "reinstall"


# remove /tmp/log/reinstall.log
rm -f "$tmpfile"


# clear potential terminal buffer
sript -q /dev/null tput clear > /dev/null 2>&1

==> macdaily-2018.9.11.post1.tar.gz: macdaily-2018.9.11.post1/macdaily/libprinstall/reinstall_cask.sh <==
#!/bin/bash


# clear potential terminal buffer
sript -q /dev/null tput clear > /dev/null 2>&1


# terminal display
reset="\033[0m"         # reset
bold="\033[1m"          # bold
red="\033[91m"          # bright red foreground
green="\033[92m"        # bright green foreground
yellow="\033[93m"       # bright yellow foreground


################################################################################
# Reinstall Caskroom packages.
#
# Parameter list:
#   1. Encrypted Password
#   2. Log File
#   3. Temp File
#   4. Quiet Flag
#   5. Verbose Flag
#   6. Package
#       ............
################################################################################


# parameter assignment
password=`python -c "print(__import__('base64').b64decode(__import__('sys').stdin.readline().strip()).decode())" <<< $1`
# echo $1 | cut -c2- | rev | cut -c2- | rev
logfile=`python -c "print(__import__('sys').stdin.readline().strip().strip('\''))" <<< $2`
tmpfile=`python -c "print(__import__('sys').stdin.readline().strip().strip('\''))" <<< $3`
arg_q=$4
arg_v=$5
arg_pkg=${*:6}


# remove /tmp/log/reinstall.log
rm -f "$tmpfile"


# create /tmp/log/reinstall.log & /Library/Logs/Scripts/reinstall/logdate.log
touch "$logfile"
touch "$tmpfile"


# log current status
echo "- /bin/bash $0 $@" >> "$tmpfile"


# log commands
logprefix="script -aq "$tmpfile""
if ( $arg_q ) ; then
    logsuffix="grep ^$"
else
    logsuffix="grep ^.*$"
fi


# if quiet flag set
if ( $arg_q ) ; then
    quiet="--quiet"
else
    quiet=""
fi


# if verbose flag set
if ( $arg_v ) ; then
    verbose="--verbose"
else
    verbose=""
fi


# reinstall procedure
for name in $arg_pkg ; do
    flag=`brew cask list -1 | awk "/^$name$/"`
    if [[ ! -z $flag ]] ; then
        # ask for password up-front
        sudo --reset-timestamp
        sudo --stdin --validate <<< $password ; echo

        $logprefix printf "+ ${bold}brew cask reinstall $name $verbose $quiet${reset}\n" | $logsuffix
        if ( $arg_q ) ; then
            $logprefix brew cask reinstall $name $verbose $quiet > /dev/null 2>&1
        else
            $logprefix brew cask reinstall $name $verbose $quiet
        fi
        $logprefix echo | $logsuffix
    else
        $logprefix printf "reinstall: ${yellow}brew${reset}: no formula names ${red}$name${reset} installed\n" | $logsuffix

        # did you mean
        tmp=`brew list -1 | grep $name | xargs`
        if [[ ! -z $tmp ]] ; then
            dym=`python -c "print('${red}' + '${reset}, ${red}'.join(__import__('sys').stdin.read().strip().split()) + '${reset}')" <<< $tmp`
            $logprefix printf "reinstall: ${yellow}brew${reset}: did you mean any of the following formulae: $dym?\n" | $logsuffix
        fi
        $logprefix echo | $logsuffix
    fi
done


# aftermath works
bash ./libprinstall/aftermath.sh "$logfile" "$tmpfile" "false" "reinstall"


# remove /tmp/log/reinstall.log
rm -f "$tmpfile"


# clear potential terminal buffer
sript -q /dev/null tput clear > /dev/null 2>&1
